@@ -118,6 +118,7 @@ sub generate { return (rand() < 0.5); }
 sub validate { return looks_like_number($_[1]) ? ($_[1] == 0 || $_[1] == 1) : (lc($_[1]) == 'true' || lc($_[1]) == 'false'); }
 sub data_type { return WWW::Shopify::Field::TYPE_BOOLEAN; }
 sub to_shopify { return $_[1] ? JSON::true : JSON::false; }
+sub from_shopify { return $_[1] ? 1 : 0; }
 
 package WWW::Shopify::Field::Float;
 use parent 'WWW::Shopify::Field';
@@ -353,6 +354,16 @@ sub from_shopify {
 			time_zone => $7 . $8,
 		);
 	}
+	elsif ($_[1] =~ m/(\d+)-(\d+)-(\d+)T(\d+):(\d+):(\d+)/) {
+		$dt = DateTime->new(
+			year      => $1,
+			month     => $2,
+			day       => $3,
+			hour      => $4,
+			minute    => $5,
+			second    => $6,
+		);
+	}
 	else {
 		die new WWW::Shopify::Exception("Unable to parse date " . $_[1]) unless $_[1] =~ m/(\d+)-(\d+)-(\d+)/;
 		$dt = DateTime->new(
@@ -383,4 +394,13 @@ sub validate { return !defined $_[1] || (ref($_[1]) && ref($_[1]) eq "HASH"); }
 sub to_shopify { return $_[1]; }
 sub from_shopify { return $_[1]; }
 
+package WWW::Shopify::Field::Freeform::Array;
+use parent 'WWW::Shopify::Field';
+sub sql_type { return "text"; }
+sub generate { return []; }
+sub data_type { return WWW::Shopify::Field::TYPE_QUALITATIVE; }
+sub validate { return !defined $_[1] || (ref($_[1]) && ref($_[1]) eq "ARRAY"); }
+sub to_shopify { return $_[1]; }
+sub from_shopify { return $_[1]; }
+
 1;
