@@ -31,7 +31,10 @@ sub update_filled { return qw(); }
 
 sub actions { return qw(disable enable); }
 
+sub countable { return 0; }
+
 sub needs_login { return 1; }
+sub needs_plus { return 1; }
 
 eval(__PACKAGE__->generate_accessors); die $@ if $@;
 
