@@ -6,6 +6,8 @@ use warnings;
 package WWW::Shopify::Model::Item;
 use DateTime;
 use WWW::Shopify::Query;
+use WWW::Shopify::Field;
+use WWW::Shopify::Field::String;
 
 =head1 NAME
 
@@ -113,6 +115,11 @@ sub plural { return $_[0]->singular() . "s"; }
 
 
 sub needs_login { return undef; }
+sub needs_form_encoding_get_all { return undef; }
+sub needs_form_encoding_get { return undef; }
+sub needs_form_encoding_create { return undef; }
+sub needs_form_encoding_update { return undef; }
+sub needs_form_encoding_delete { return undef; }
 
 =head2 needs_plus($package)
 
@@ -148,6 +155,7 @@ Determines whether or not this package can perform these main actions. 1 for yes
 
 sub countable { return 1; }
 sub gettable { return 1; }
+# Whether or not we can get it as a single entity, by ID.
 sub singlable { return $_[0]->gettable; }
 sub creatable { return 1; }
 sub updatable { my @fields = $_[0]->update_fields; return int(@fields) > 0; }
@@ -392,12 +400,14 @@ sub from_json {
 			if ($ref->{$_}->is_relation()) {
 				my $package = $ref->{$_}->relation();
 				if ($ref->{$_}->is_many()) {
-					next unless exists $json->{$package->plural()};
+					# This may not be necesasry, but this is such fundamental code I don't want to mess with it.
+					next unless exists $json->{$package->plural()} || exists $json->{$_};
+					my @objects = exists $json->{$package->plural()} ? @{$json->{$package->plural()}} : @{$json->{$_}};
 					$self->{$_} = [map {
 						my $o = $package->from_json($_, $associated);
 						$o->associated_parent($self);
 						$o;
-					} @{$json->{$package->plural()}}];
+					} @objects];
 				}
 				elsif ($ref->{$_}->is_one && $ref->{$_}->is_own) {
 					next unless (exists $json->{$_});
