@@ -16,7 +16,7 @@ BEGIN { $fields = {
 	"country" => new WWW::Shopify::Field::String("[A-Z]{3}"),
 	"country_name" => new WWW::Shopify::Field::String::Country(),
 	"country_code" => new WWW::Shopify::Field::String("[A-Z]{3}"),
-	"created_at" => new WWW::Shopify::Field::Date(min => '2010-01-01 00:00:00', max => 'now'),
+	"created_at" => new WWW::Shopify::Field::Date(),
 	"customer_email" => new WWW::Shopify::Field::String::Email(),
 	"domain" => new WWW::Shopify::Field::String::Hostname(),
 	"email" => new WWW::Shopify::Field::String::Email(),
@@ -28,9 +28,10 @@ BEGIN { $fields = {
 	"province_code" => new WWW::Shopify::Field::String("[A-Z]{3}"),
 	"public" => new WWW::Shopify::Field::String(),
 	"source" => new WWW::Shopify::Field::String(),
-	"display_plan_name" => new WWW::Shopify::Field::String(),
+	"display_plan_name" => new WWW::Shopify::Field::String::Enum([qw(development affiliate unlimited professional basic shopify_plus custom business dormant comped trial starter staff npo_full singtel_professional nonprofit rogers_basic singtel_starter singtel_basic uafrica_basic npo_lite)]),
 	"zip" => new WWW::Shopify::Field::String("[A-Z][0-9][A-Z] [0-9][A-Z][0-9]"),
 	"currency" => new WWW::Shopify::Field::Currency(),
+	"iana_timezone" => new WWW::Shopify::Field::Timezone(),
 	"timezone" => new WWW::Shopify::Field::Timezone(),
 	"latitude" => new WWW::Shopify::Field::Float(),
 	"longitude" => new WWW::Shopify::Field::Float(),
@@ -39,7 +40,7 @@ BEGIN { $fields = {
 	"money_with_currency_format" => new WWW::Shopify::Field::String("\$ \{\{amount\}\} USD"),
 	"taxes_included" => new WWW::Shopify::Field::String(),
 	"tax_shipping" => new WWW::Shopify::Field::String(),
-	"plan_name" => new WWW::Shopify::Field::String::Words(1),
+	"plan_name" => new WWW::Shopify::Field::String::Enum([qw(development affiliate unlimited professional basic shopify_plus custom business dormant comped trial starter staff npo_full singtel_professional nonprofit rogers_basic singtel_starter singtel_basic uafrica_basic npo_lite)]),
 	"myshopify_domain" => new WWW::Shopify::Field::String::Hostname::Shopify(),
 	"metafields" => new WWW::Shopify::Field::Relation::Many("WWW::Shopify::Model::Metafield")
 }; }
