@@ -60,34 +60,64 @@ sub get_url {
 
 use URI::Escape;
 use JSON qw(encode_json);
+use Scalar::Util qw(reftype);
 
 sub use_url{
-	my ($self, $method, $url, $hash, $needs_login, $type) = @_;
+	my ($self, $method, $url, $hash, $needs_login, $type, $accept) = @_;
 	$type = "application/json" unless $type;
+	$accept = "application/json" unless $accept;
 	my $request = HTTP::Request->new($method, $url);
-	$request->header("Accept" => "application/json", "Content-Type" => $type);
+	$request->header("Accept" => $accept, "Content-Type" => $type);
 	if ($type =~ m/json/) {
 		$request->content($hash ? encode_json($hash) : undef);
 	} else {
-		$request->content(join("&", map { my $name = uri_escape_utf8($_); map { $name . "=" . uri_escape_utf8($_) } ($hash->{$_} && ref($hash->{$_}) eq "ARRAY" ? @{$hash->{$_}} : ($hash->{$_})) } keys(%$hash))) if $hash;
+		if ($hash) {
+			sub flatten_object {
+				my ($prefix, $object) = @_;
+				return map {  
+					my $key = $_;
+					my @items;
+					@items = flatten_object($prefix . $key, $object->{$key}) if reftype($object->{$key}) && reftype($object->{$key}) eq "HASH";
+					@items = (map { flatten_object($prefix . "[" . $key . "][]", $_) } @{$object->{$key}}) if reftype($object->{$key}) && reftype($object->{$key}) eq "ARRAY";
+					@items = ($prefix . "[" . $key . "]=" . uri_escape_utf8(defined $object->{$key} ? $object->{$key} : '')) if !reftype($object->{$key});
+					
+					
+					@items;
+				} keys(%$object);
+			}
+			$request->content(join("&", map { 
+				if (reftype($hash->{$_}) && reftype($hash->{$_}) eq "HASH") {
+					flatten_object($_, $hash->{$_});
+				} else {
+					my $name = uri_escape_utf8($_); 
+					map { $name . "=" . uri_escape_utf8($_) } ($hash->{$_} && ref($hash->{$_}) eq "ARRAY" ? @{$hash->{$_}} : ($hash->{$_})) 
+				}
+			} keys(%$hash) ));
+		}
 	}
 	my $response = $self->parent->ua->request($request);
-	if (!$response->is_success) {
-		die new WWW::Shopify::Exception::CallLimit($response) if $response->code() == 429;
-		die new WWW::Shopify::Exception::InvalidKey($response) if $response->code() == 401;
-		die new WWW::Shopify::Exception($response);
+	if ($type =~ m/json/) {
+		if (!$response->is_success) {
+			die new WWW::Shopify::Exception::CallLimit($response) if $response->code() == 429;
+			die new WWW::Shopify::Exception::InvalidKey($response) if $response->code() == 401;
+			die new WWW::Shopify::Exception($response);
+		}
+		my $limit = $response->header('x-shopify-shop-api-call-limit');
+		if ($limit) {
+			die new WWW::Shopify::Exception("Unrecognized limit.") unless $limit =~ m/(\d+)\/\d+/;
+			$self->parent->api_calls($1);
+		}
+		my $content = $response->decoded_content;
+		# From JSON because decodec content is already a perl internal string.
+		# Sigh. No. It's not. As per https://rt.cpan.org/Public/Bug/Display.html?id=82963; decoded_content doesn't actually do anything.
+		$content = decode("UTF-8", $content) if ($response->header('Content-Type') =~ m/application\/json/);
+		my $decoded = (length($content) >= 2 && (!$response->header('Content-Type') || $response->header('Content-Type') =~ /json/ ? from_json($content) : undef));
+		return ($decoded, $response);
+	} else {
+		if ($response->is_redirect) {
+			
+		}
 	}
-	my $limit = $response->header('x-shopify-shop-api-call-limit');
-	if ($limit) {
-		die new WWW::Shopify::Exception("Unrecognized limit.") unless $limit =~ m/(\d+)\/\d+/;
-		$self->parent->api_calls($1);
-	}
-	my $content = $response->decoded_content;
-	# From JSON because decodec content is already a perl internal string.
-	# Sigh. No. It's not. As per https://rt.cpan.org/Public/Bug/Display.html?id=82963; decoded_content doesn't actually do anything.
-	$content = decode("UTF-8", $content) if ($response->header('Content-Type') =~ m/application\/json/);
-	my $decoded = (length($content) >= 2 && (!$response->header('Content-Type') || $response->header('Content-Type') =~ /json/ ? from_json($content) : undef));
-	return ($decoded, $response);
 }
 sub put_url { return shift->use_url("PUT", @_); }
 sub post_url { return shift->use_url("POST", @_); }
